#
# for "pytest_relay_run"
#

@host = localhost
@port = 8000
@api = {{host}}:{{port}}/api
# @id = 9fc2cc2b-36e7-4177-855e-0ba56e4cd800
@id = 2025-08-31_16:12:00

###
POST http://{{api}}/jobs
content-type: application/json

{
    "id": "{{id}}",
    "args": ["/Users/martin/Documents/code/pytest-relay/test-files/discovery/test_a/sub_package_c", "--strip-paths"],
    "collect_only": true
}

###
DELETE http://{{api}}/jobs

###
GET http://{{api}}/jobs/{{id}}

###
POST http://{{api}}/jobs/{{id}}/actions
content-type: application/json

{
    "action": "start"
}

###
POST http://{{api}}/jobs/{{id}}/actions
content-type: application/json

{
    "action": "stop"
}

###
DELETE http://{{api}}/jobs/{{id}}

###
DELETE http://{{api}}/jobs

###
GET http://{{api}}/jobs
